powered by
Gets the number of the dimensions of each parameter of an object.
The default methods returns the length of each element of pdims() as an integer vector.
pdims()
# S3 method for nlists npdims(x, ...)
A named integer vector of the number of dimensions of each parameter.
An object.
Other arguments passed to methods.
Other dimensions: dims(), ndims(), pdims()
dims()
ndims()
npdims(nlists(nlist(x = 1:3))) npdims(nlists( nlist(y = 3, zz = matrix(2:5, 2)), nlist(y = 5, zz = matrix(1:4, 2)) ))
Run the code above in your browser using DataLab