Learn R Programming

nlist (version 0.5.0)

tidy.mcmc.list: Turn an object into a tidy tibble

Description

Turn an object into a tidy tibble

Usage

# S3 method for mcmc.list
tidy(x, simplify = TRUE, directional_information = FALSE, ...)

Value

A tibble::tibble() with information about model components.

Arguments

x

An object.

simplify

A flag specifying whether to drop the sd and zscore columns. simplify = FALSE is deprecated.

directional_information

A flag specifying whether the svalue column should be calculated using extras::directional_information() instead of extras::svalue(). The default value will change from FALSE to TRUE in a future release; set the argument explicitly to avoid the deprecation warning.

...

Unused.

Methods

generics:::methods_rd("tidy")