Parameter Descriptions
An object.
A positive integer of the thinning rate.
Unused.
An atomic vector
An nlist object.
A logical scalar specifying whether to include all parameters (NULL), only scalars (TRUE) or all parameters except scalars (FALSE).
A flag specifying whether to return the parameter name for each term element.
An integer vector of chains.
An integer vector of iterations.
A character vector of parameter names.
A function that given a numeric vector returns a numeric scalar.
A flag specifying whether to also fill missing values.
A character vector (or NULL) of the parameters to subset by.
An integer vector (or NULL) of the iterations to subset by.
A flag specifying whether to drop the sd and zscore
columns. simplify = FALSE is deprecated.
A flag specifying whether the svalue column
should be calculated using extras::directional_information() instead of
extras::svalue().
The default value will change from FALSE to TRUE in a future release;
set the argument explicitly to avoid the deprecation warning.
A flag specifying whether to suppress warning messages.
A flag specifying whether to aggregate by chains.