Turn an object into a tidy tibble
# S3 method for mcmc.list
tidy(x, simplify = TRUE, directional_information = FALSE, ...)A tibble::tibble() with information about model components.
An object.
A flag specifying whether to drop the sd and zscore
columns. simplify = FALSE is deprecated.
A flag specifying whether the svalue column
should be calculated using extras::directional_information() instead of
extras::svalue().
The default value will change from FALSE to TRUE in a future release;
set the argument explicitly to avoid the deprecation warning.
Unused.
generics:::methods_rd("tidy")